"""
SSH utilities and MCP tools.

This package provides a minimal SSH executor (Paramiko-based) and MCP tools
to run remote commands and create files over SSH.
"""

# ruff: noqa: F401, E402
import src.SSH.tools

__all__ = ["tools"]
